@@ -24,6 +24,12 @@ DimDisplay::DimDisplay(QObject *parent)
     : Action(parent)
 {
     setRequiredPolicies(PowerDevil::PolicyAgent::ChangeScreenSettings);
+
+    // Listen to the policy agent
+    auto policyAgent = PowerDevil::PolicyAgent::instance();
+    connect(policyAgent, &PowerDevil::PolicyAgent::unavailablePoliciesChanged, this, &DimDisplay::onUnavailablePoliciesChanged);
+
+    m_inhibitScreen = policyAgent->unavailablePolicies() & PowerDevil::PolicyAgent::ChangeScreenSettings;
 }
 
 void DimDisplay::onWakeupFromIdle()
@@ -34,7 +40,8 @@ void DimDisplay::onWakeupFromIdle()
     // An active inhibition may not let us restore the brightness.
     // We should wait a bit screen to wake-up from sleep
     QTimer::singleShot(0, this, [this]() {
-        setBrightnessHelper(m_oldScreenBrightness, m_oldKeyboardBrightness, true);
+        qCDebug(POWERDEVIL) << "DimDisplay: restoring brightness on wake-up from idle";
+        setBrightnessHelper(m_oldScreenBrightness, m_oldKeyboardBrightness);
     });
     m_dimmed = false;
 }
@@ -42,7 +49,8 @@ void DimDisplay::onWakeupFromIdle()
 void DimDisplay::onIdleTimeout(std::chrono::milliseconds timeout)
 {
     Q_ASSERT(timeout == m_dimOnIdleTime);
-    if (m_dimmed) {
+    if (m_dimmed || m_inhibitScreen) {
+        qCDebug(POWERDEVIL) << "DimDisplay: inhibited (or already dimmed), not dimming";
         return;
     }
 
@@ -53,6 +61,7 @@ void DimDisplay::onIdleTimeout(std::chrono::milliseconds timeout)
         // Furthermore, we can't dim if brightness is 0 already.
         return;
     }
+    qCDebug(POWERDEVIL) << "DimDisplay: triggered on idle timeout, dimming";
 
     m_oldScreenBrightness = backend()->screenBrightness();
     m_oldKeyboardBrightness = backend()->keyboardBrightness();
@@ -67,28 +76,23 @@ void DimDisplay::onIdleTimeout(std::chrono::milliseconds timeout)
     m_dimmed = true;
 }
 
-void DimDisplay::setBrightnessHelper(int screen, int keyboard, bool force)
-{
-    trigger({
-        {QStringLiteral("_ScreenBrightness"), QVariant::fromValue(screen)},
-        {QStringLiteral("_KeyboardBrightness"), QVariant::fromValue(keyboard)},
-        {QStringLiteral("Explicit"), QVariant::fromValue(force)},
-    });
-}
-
-void DimDisplay::triggerImpl(const QVariantMap &args)
+void DimDisplay::setBrightnessHelper(int screenBrightness, int keyboardBrightness)
 {
     // don't arbitrarily turn-off the display
-    if (m_oldScreenBrightness > 0) {
-        backend()->setScreenBrightness(args.value(QStringLiteral("_ScreenBrightness")).toInt());
+    if (screenBrightness > 0) {
+        backend()->setScreenBrightness(screenBrightness);
     }
 
     // don't manipulate keyboard brightness if it's already zero to prevent races with DPMS action
     if (m_oldKeyboardBrightness > 0) {
-        backend()->setKeyboardBrightness(args.value(QStringLiteral("_KeyboardBrightness")).toInt());
+        backend()->setKeyboardBrightness(keyboardBrightness);
     }
 }
 
+void DimDisplay::triggerImpl(const QVariantMap & /*args*/)
+{
+}
+
 bool DimDisplay::isSupported()
 {
     return backend()->screenBrightnessAvailable();
@@ -96,7 +100,6 @@ bool DimDisplay::isSupported()
 
 bool DimDisplay::loadAction(const PowerDevil::ProfileSettings &profileSettings)
 {
-    qCDebug(POWERDEVIL);
     // when profile is changed after display is dimmed or turn-off (by dpms)
     // 1. restore brightness values if current loaded profile doesn't require dimming
     // 2. update brightness values to new ones if there are explicitly set
@@ -104,6 +107,7 @@ bool DimDisplay::loadAction(const PowerDevil::ProfileSettings &profileSettings)
     if (!profileSettings.dimDisplayWhenIdle()) {
         if (m_dimmed) {
             if (!profileSettings.useProfileSpecificDisplayBrightness() && m_oldScreenBrightness > 0) {
+                qCDebug(POWERDEVIL) << "DimDisplay: restoring brightness on reload";
                 backend()->setScreenBrightness(m_oldScreenBrightness);
             }
             if (!profileSettings.useProfileSpecificKeyboardBrightness() && m_oldKeyboardBrightness > 0) {
@@ -124,11 +128,15 @@ bool DimDisplay::loadAction(const PowerDevil::ProfileSettings &profileSettings)
     }
 
     m_dimOnIdleTime = std::chrono::seconds(profileSettings.dimDisplayIdleTimeoutSec());
-    qCDebug(POWERDEVIL) << "Loading timeouts with " << m_dimOnIdleTime.count();
+    qCDebug(POWERDEVIL) << "DimDisplay: registering idle timeout after" << m_dimOnIdleTime;
     registerIdleTimeout(m_dimOnIdleTime);
     return true;
 }
 
+void DimDisplay::onUnavailablePoliciesChanged(PowerDevil::PolicyAgent::RequiredPolicies policies)
+{
+    m_inhibitScreen = policies & PowerDevil::PolicyAgent::ChangeScreenSettings;
+}
 }
 
 #include "dimdisplay.moc"
