@@ -10,7 +10,6 @@
 #include <KQuickManagedConfigModule>
 
 #include <QList>
-#include <QQmlEngine>
 #include <QVariant>
 
 // Profile configuration for PowerDevil, i.e. separate settings for AC/Battery/LowBattery power states
@@ -22,41 +21,33 @@ class SleepModeModel;
 namespace PowerDevil
 {
 class ProfileSettings;
+class GlobalSettings;
+class ExternalServiceSettings;
 
-class ProfileConfigData : public KCModuleData
+class ProfilesConfigData : public KCModuleData
 {
     Q_OBJECT
 
-    Q_PROPERTY(QString profileId READ profileId CONSTANT)
-    Q_PROPERTY(QObject *settings READ settings CONSTANT)
-    Q_PROPERTY(QObject *autoSuspendActionModel READ autoSuspendActionModel CONSTANT)
-    Q_PROPERTY(QObject *powerButtonActionModel READ powerButtonActionModel CONSTANT)
-    Q_PROPERTY(QObject *lidActionModel READ lidActionModel CONSTANT)
-    Q_PROPERTY(QObject *sleepModeModel READ sleepModeModel CONSTANT)
-    Q_PROPERTY(QObject *powerProfileModel READ powerProfileModel CONSTANT)
+    Q_PROPERTY(QObject *global READ global CONSTANT)
+    Q_PROPERTY(QObject *profileAC READ profileAC CONSTANT)
+    Q_PROPERTY(QObject *profileBattery READ profileBattery CONSTANT)
+    Q_PROPERTY(QObject *profileLowBattery READ profileLowBattery CONSTANT)
 
 public:
-    explicit ProfileConfigData(const QString &profileId, bool isMobile, bool isVM, bool canSuspend, QObject *parent);
-    ~ProfileConfigData() override;
+    explicit ProfilesConfigData(QObject *parent, const KPluginMetaData &metaData);
+    explicit ProfilesConfigData(QObject *parent, bool isMobile, bool isVM, bool canSuspend, bool canHibernate);
+    ~ProfilesConfigData() override;
 
-    QString profileId() const;
-    ProfileSettings *settings() const;
-
-    QObject *autoSuspendActionModel() const;
-    QObject *powerButtonActionModel() const;
-    QObject *lidActionModel() const;
-    QObject *sleepModeModel() const;
-    QObject *powerProfileModel() const;
+    GlobalSettings *global() const;
+    ProfileSettings *profileAC() const;
+    ProfileSettings *profileBattery() const;
+    ProfileSettings *profileLowBattery() const;
 
 private:
-    QString m_profileId;
-    ProfileSettings *m_settings;
-
-    PowerButtonActionModel *m_autoSuspendActionModel;
-    PowerButtonActionModel *m_powerButtonActionModel;
-    PowerButtonActionModel *m_lidActionModel;
-    SleepModeModel *m_sleepModeModel;
-    PowerProfileModel *m_powerProfileModel;
+    GlobalSettings *m_globalSettings;
+    ProfileSettings *m_settingsAC;
+    ProfileSettings *m_settingsBattery;
+    ProfileSettings *m_settingsLowBattery;
 };
 
 class ProfilesConfigKCM : public KQuickManagedConfigModule
@@ -66,26 +57,58 @@ class ProfilesConfigKCM : public KQuickManagedConfigModule
     // e.g. {"BrightnessControl": true, "KeyboardBrightnessControl": false, "SuspendSession": true, ...}
     Q_PROPERTY(QVariantMap supportedActions READ supportedActions NOTIFY supportedActionsChanged)
 
-    Q_PROPERTY(QVariantMap profileData READ profileData CONSTANT)
+    Q_PROPERTY(QObject *settings READ settings CONSTANT)
+    Q_PROPERTY(QObject *externalServiceSettings READ externalServiceSettings CONSTANT)
     Q_PROPERTY(QString currentProfile READ currentProfile NOTIFY currentProfileChanged)
     Q_PROPERTY(bool supportsBatteryProfiles READ supportsBatteryProfiles NOTIFY supportsBatteryProfilesChanged)
+
+    Q_PROPERTY(bool isPowerSupplyBatteryPresent READ isPowerSupplyBatteryPresent NOTIFY isPowerSupplyBatteryPresentChanged)
+    Q_PROPERTY(bool isPeripheralBatteryPresent READ isPeripheralBatteryPresent NOTIFY isPeripheralBatteryPresentChanged)
     Q_PROPERTY(bool isLidPresent READ isLidPresent NOTIFY isLidPresentChanged)
     Q_PROPERTY(bool isPowerButtonPresent READ isPowerButtonPresent NOTIFY isPowerButtonPresentChanged)
 
+    Q_PROPERTY(bool isChargeStartThresholdSupported READ isChargeStartThresholdSupported NOTIFY isChargeStartThresholdSupportedChanged)
+    Q_PROPERTY(bool isChargeStopThresholdSupported READ isChargeStopThresholdSupported NOTIFY isChargeStopThresholdSupportedChanged)
+    Q_PROPERTY(bool chargeStopThresholdMightNeedReconnect READ chargeStopThresholdMightNeedReconnect NOTIFY chargeStopThresholdMightNeedReconnectChanged)
+
     Q_PROPERTY(bool powerManagementServiceRegistered READ powerManagementServiceRegistered NOTIFY powerManagementServiceRegisteredChanged)
     Q_PROPERTY(QString powerManagementServiceErrorReason READ powerManagementServiceErrorReason NOTIFY powerManagementServiceErrorReasonChanged)
 
+    Q_PROPERTY(QObject *autoSuspendActionModel READ autoSuspendActionModel CONSTANT)
+    Q_PROPERTY(QObject *batteryCriticalActionModel READ batteryCriticalActionModel CONSTANT)
+    Q_PROPERTY(QObject *powerButtonActionModel READ powerButtonActionModel CONSTANT)
+    Q_PROPERTY(QObject *lidActionModel READ lidActionModel CONSTANT)
+    Q_PROPERTY(QObject *sleepModeModel READ sleepModeModel CONSTANT)
+    Q_PROPERTY(QObject *powerProfileModel READ powerProfileModel CONSTANT)
+
 public:
     ProfilesConfigKCM(QObject *parent, const KPluginMetaData &metaData);
 
+    bool isSaveNeeded() const override;
+
     QVariantMap supportedActions() const;
 
-    QVariantMap profileData() const;
+    ProfilesConfigData *settings() const;
+    ExternalServiceSettings *externalServiceSettings() const;
     QString currentProfile() const;
     bool supportsBatteryProfiles() const;
+
+    bool isPowerSupplyBatteryPresent() const;
+    bool isPeripheralBatteryPresent() const;
     bool isLidPresent() const;
     bool isPowerButtonPresent() const;
 
+    bool isChargeStartThresholdSupported() const;
+    bool isChargeStopThresholdSupported() const;
+    bool chargeStopThresholdMightNeedReconnect() const;
+
+    QObject *autoSuspendActionModel() const;
+    QObject *batteryCriticalActionModel() const;
+    QObject *powerButtonActionModel() const;
+    QObject *lidActionModel() const;
+    QObject *sleepModeModel() const;
+    QObject *powerProfileModel() const;
+
     bool powerManagementServiceRegistered() const;
     QString powerManagementServiceErrorReason() const;
 
@@ -98,15 +121,25 @@ Q_SIGNALS:
 
     void currentProfileChanged();
     void supportsBatteryProfilesChanged();
+
+    void isPowerSupplyBatteryPresentChanged();
+    void isPeripheralBatteryPresentChanged();
     void isLidPresentChanged();
     void isPowerButtonPresentChanged();
 
+    void isChargeStartThresholdSupportedChanged();
+    void isChargeStopThresholdSupportedChanged();
+    void chargeStopThresholdMightNeedReconnectChanged();
+
     void powerManagementServiceRegisteredChanged();
     void powerManagementServiceErrorReasonChanged();
 
 private:
     void setCurrentProfile(const QString &currentProfile);
     void setSupportsBatteryProfiles(bool);
+
+    void setPowerSupplyBatteryPresent(bool);
+    void setPeripheralBatteryPresent(bool);
     void setLidPresent(bool);
     void setPowerButtonPresent(bool);
 
@@ -117,14 +150,25 @@ private:
 
     QVariantMap m_supportedActions;
 
-    QVariantMap m_profileData;
+    ProfilesConfigData *m_settings;
+    ExternalServiceSettings *m_externalServiceSettings;
     QString m_currentProfile;
     bool m_supportsBatteryProfiles;
+
+    bool m_isPowerSupplyBatteryPresent;
+    bool m_isPeripheralBatteryPresent;
     bool m_isLidPresent;
     bool m_isPowerButtonPresent;
 
     bool m_powerManagementServiceRegistered;
     QString m_powerManagementServiceErrorReason;
+
+    PowerButtonActionModel *m_autoSuspendActionModel;
+    PowerButtonActionModel *m_batteryCriticalActionModel;
+    PowerButtonActionModel *m_powerButtonActionModel;
+    PowerButtonActionModel *m_lidActionModel;
+    SleepModeModel *m_sleepModeModel;
+    PowerProfileModel *m_powerProfileModel;
 };
 
 } // namespace PowerDevil
